mockEnabled property
Simulates internet responses using offline mock data files.
When true, requests intercept their calls and return local simulation mock files instead of going to the actual internet.
Excellent for testing when your backend server is down or still being built.
Implementation
final bool mockEnabled;