LikeSelectorSliver<N, T extends Object> class

A specialized sliver version of LikeSelector for use in CustomScrollView. Matches the exact signature of the original StateSelectorSliver.

Inheritance

Constructors

LikeSelectorSliver({Key? key, required LikeStateResponse selector(N notifier), required List<Widget> onSuccess(T data, bool isRefreshing, bool isFromStaleWhileRevalidate), List<Widget> onLoading()?, List<Widget> onIdle()?, List<Widget> onError(LikeError error)?, List<Widget> onException(String message)?, void listener(LikeStateResponse response)?})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
listener → void Function(LikeStateResponse response)?
An optional side-effect listener that triggers every time the selected state changes.
final
onError List<Widget> Function(LikeError error)?
Optional builder called when an explicit LikeError occurs.
final
onException List<Widget> Function(String message)?
Optional builder called when an unexpected exception or system error occurs.
final
onIdle List<Widget> Function()?
Optional builder called when the state is LikeState.idle.
final
onLoading List<Widget> Function()?
Optional builder called when the state is LikeState.loading.
final
onSuccess List<Widget> Function(T data, bool isRefreshing, bool isFromStaleWhileRevalidate)
Builder function called when the selected state contains successful data. Returns a list of slivers.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selector LikeStateResponse Function(N notifier)
Selects the LikeStateResponse to observe from a specific notifier N.
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited