LikeStateResponseBuilder<T> class

A specialized version of LikeBuilder that takes a LikeStateResponse directly. Useful when you already have the response object (e.g. from a Stream or local variable).

Inheritance

Constructors

LikeStateResponseBuilder({Key? key, required LikeStateResponse<T> response, required Widget onSuccess(T data, bool isRefreshing, bool isFromStaleWhileRevalidate), Widget onLoading()?, Widget onIdle()?, Widget onError(LikeError error)?, Widget onException(String message)?})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onError Widget Function(LikeError error)?
Optional builder called when an explicit LikeError occurs.
final
onException Widget Function(String message)?
Optional builder called when an unexpected exception or system error occurs.
final
onIdle Widget Function()?
Optional builder called when the state is LikeState.idle.
final
onLoading Widget Function()?
Optional builder called when the initial data load is in progress.
final
onSuccess Widget Function(T data, bool isRefreshing, bool isFromStaleWhileRevalidate)
Builder function called when data is successfully retrieved.
final
response LikeStateResponse<T>
The LikeStateResponse to build the UI from.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited