MockController class

Constructors

MockController()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isEngineEnabled ValueNotifier<bool>
final
rules ValueNotifier<List<MockRule>>
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addRule(MockRule rule) Future<void>
deleteRule(String id) Future<void>
importRules(List<MockRule> newRules, {bool clearExisting = false}) Future<void>
init() Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setEngineEnabled(bool enabled) Future<void>
toggleRule(String id) Future<void>
toString() String
A string representation of this object.
inherited
updateRule(MockRule rule) Future<void>

Operators

operator ==(Object other) bool
The equality operator.
inherited