offlineSyncEnabled property
Enables the offline queue for persisting mutation requests (POST/PUT/DELETE).
Implementation
final bool offlineSyncEnabled;
Enables the offline queue for persisting mutation requests (POST/PUT/DELETE).
final bool offlineSyncEnabled;