LikeEvent<T> class
A typed event emitted by the LikePipeline. Carries both the raw Response and potentially a ready-to-use mapped model.
Constructors
Properties
- data → dynamic
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasModel → bool
-
no setter
- isSyncing → bool
-
final
- key → String
-
final
- model → T?
-
final
- response → Response
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited