LikeSliverBuilder<T extends Object> class
A sliver version of LikeBuilder for rendering states in a CustomScrollView. Handles LikeStateResponse and provides sticky data support for slivers. Matches the exact signature of the original StateBuilderSliver.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- LikeSliverBuilder
Constructors
-
LikeSliverBuilder({Key? key, required dynamic observe(), required List<
Widget> onSuccess(T data, bool isRefreshing, bool isFromStaleWhileRevalidate), List<Widget> onLoading()?, List<Widget> onIdle()?, List<Widget> onError(LikeError error)?, List<Widget> onException(String message)?, void listener(LikeStateResponse response)?}) -
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- listener → void Function(LikeStateResponse response)?
-
An optional side-effect listener that triggers every time the observed state changes.
final
- observe → dynamic Function()
-
A function that returns the current LikeStateResponse or LikeNotifierState to observe.
final
-
onError
→ List<
Widget> Function(LikeError error)? -
Optional builder called when an explicit LikeError occurs.
final
-
onException
→ List<
Widget> Function(String message)? -
Optional builder called when an unexpected exception or system error occurs.
final
-
onIdle
→ List<
Widget> Function()? -
Optional builder called when the state is LikeState.idle.
final
-
onLoading
→ List<
Widget> Function()? -
Optional builder called when the initial load is in progress.
final
-
onSuccess
→ List<
Widget> Function(T data, bool isRefreshing, bool isFromStaleWhileRevalidate) -
Builder function called when data is successfully retrieved.
Returns a list of sliver widgets.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< LikeSliverBuilder< T> > -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited